@@ -65,7 +65,7 @@ class NxPyDocs():
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                if self.filetype:
+                if self.filetype != "none":
                     if self.repo != "none":
                         self.clone()
                         self.pick_filetype(parsed_json)
@@ -76,10 +76,13 @@ class NxPyDocs():
                 else:
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
-                command_output = clid( '%s' % self.command )
-                parsed_json = json.loads(command_output)
-                click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
-                
+                if self.filetype != "none":
+                    click.secho("Show command not templated yet")
+                else:
+                    command_output = clid( '%s' % self.command )
+                    parsed_json = json.loads(command_output)
+                    click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
+
     def pick_filetype(self, parsed_json):
         if self.filetype == "none":
             pass
